@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2012-2020 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2012-2021 -- leonerd@leonerd.org.uk
 
 use v5.26;
-use Object::Pad 0.25;
+use Object::Pad 0.57;
 
-package Tickit::Widget::Menu::Item 0.12;
+package Tickit::Widget::Menu::Item 0.14;
 class Tickit::Widget::Menu::Item
-   implements Tickit::Widget::Menu::itembase;
+   :does(Tickit::Widget::Menu::itembase);
 
 use Tickit::Utils qw( textwidth );
 
@@ -49,12 +49,7 @@ Callback to invoke when the menu item is clicked on.
 
 =cut
 
-has $_on_activate;
-
-BUILD ( %args )
-{
-   $_on_activate = $args{on_activate};
-}
+has $_on_activate :param = undef;
 
 method activate ()
 {
