@@ -1,15 +1,15 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2012-2020 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2012-2021 -- leonerd@leonerd.org.uk
 
 use v5.26;
-use Object::Pad 0.25;
+use Object::Pad 0.57;
 
-package Tickit::Widget::Menu::base 0.12;
+package Tickit::Widget::Menu::base 0.14;
 class Tickit::Widget::Menu::base
-   extends Tickit::Widget
-   implements Tickit::Widget::Menu::itembase;
+   :isa(Tickit::Widget)
+   :does(Tickit::Widget::Menu::itembase);
 
 use Carp;
 
@@ -27,10 +27,10 @@ has @_itemwidths;
 
 has $_active_idx; # index of keyboard-selected highlight
 
-BUILD ( %args )
+ADJUSTPARAMS ( $params )
 {
-   if( $args{items} ) {
-      $self->push_item( $_ ) for @{ $args{items} };
+   if( exists $params->{items} ) {
+      $self->push_item( $_ ) for @{ delete $params->{items} };
    }
 }
 
