@@ -4,19 +4,12 @@
 #  (C) Paul Evans, 2013-2020 -- leonerd@leonerd.org.uk
 
 use v5.26;
-use Object::Pad 0.33;
+use Object::Pad 0.42;
 
-package Tickit::Widget::Menu::itembase 0.12;
+package Tickit::Widget::Menu::itembase 0.14;
 role Tickit::Widget::Menu::itembase;
 
-has $_name;
-
-BUILD ( %args )
-{
-   $_name = $args{name};
-}
-
-method name () { $_name }
+has $_name :param :reader = undef;
 
 method render_label ( $rb, $cols, $menu )
 {
