@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2012-2020 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2012-2021 -- leonerd@leonerd.org.uk
 
 use v5.26;
-use Object::Pad 0.25;
+use Object::Pad 0.57;
 
-package Tickit::Widget::MenuBar 0.12;
+package Tickit::Widget::MenuBar 0.14;
 class Tickit::Widget::MenuBar
-   extends Tickit::Widget::Menu::base;
+   :isa(Tickit::Widget::Menu::base);
 
 use Tickit::Style;
 
@@ -263,7 +263,7 @@ method key_highlight_next ( $ )
 
 method key_highlight_prev ( $ )
 {
-   $self->SUPER::key_highlight_prev;
+   $self->SUPER::key_highlight_prev( @_ );
    $self->expand_item( $self->_active_idx );
 }
 
